@@ -21,7 +21,7 @@ UINT32 getData(TCSD_PACKET_TYPE,int,void *,int,struct tcsd_comm_data *);
 void initData(struct tcsd_comm_data *, int);
 TSS_RESULT sendTCSDPacket(struct host_table_entry *);
 TSS_RESULT send_init(struct host_table_entry *);
-TSS_RESULT sendit(struct host_table_entry *);
+TSS_RESULT tcs_sendit(struct host_table_entry *);
 short get_port();
 
 /* Context commands always included */
@@ -243,7 +243,7 @@ TSS_RESULT RPC_GetCapabilitySigned_TP(struct host_table_entry *,TCS_KEY_HANDLE,T
 TSS_RESULT RPC_GetCapabilityOwner_TP(struct host_table_entry *,TPM_AUTH *,TCPA_VERSION *,UINT32 *,UINT32 *);
 TSS_RESULT RPC_SetCapability_TP(struct host_table_entry *,TCPA_CAPABILITY_AREA,UINT32,BYTE *,UINT32,BYTE *,TPM_AUTH *);
 #else
-#define RPC_GetCapability_TP(...)		TSPERR(TSS_E_INTERNAL_ERROR)
+#define RPC_GetTPMCapability_TP(...)		TSPERR(TSS_E_INTERNAL_ERROR)
 #define RPC_GetCapabilitySigned_TP(...)	TSPERR(TSS_E_INTERNAL_ERROR)
 #define RPC_GetCapabilityOwner_TP(...)		TSPERR(TSS_E_INTERNAL_ERROR)
 #define RPC_SetCapability_TP(...)		TSPERR(TSS_E_INTERNAL_ERROR)
@@ -301,8 +301,8 @@ TSS_RESULT RPC_ReadManuMaintPub_TP(struct host_table_entry *,TCPA_NONCE,TCPA_DIG
 #endif
 
 #ifdef TSS_BUILD_DAA
-TSS_RESULT RPC_DaaJoin_TP(struct host_table_entry *,TSS_HDAA,BYTE,UINT32,BYTE *,UINT32,BYTE *,TPM_AUTH *,UINT32 *,BYTE **);
-TSS_RESULT RPC_DaaSign_TP(struct host_table_entry *,TSS_HDAA,BYTE,UINT32,BYTE *,UINT32,BYTE *,TPM_AUTH *,UINT32 *,BYTE **);
+TSS_RESULT RPC_DaaJoin_TP(struct host_table_entry *,TPM_HANDLE,BYTE,UINT32,BYTE *,UINT32,BYTE *,TPM_AUTH *,UINT32 *,BYTE **);
+TSS_RESULT RPC_DaaSign_TP(struct host_table_entry *,TPM_HANDLE,BYTE,UINT32,BYTE *,UINT32,BYTE *,TPM_AUTH *,UINT32 *,BYTE **);
 #else
 #define RPC_DaaJoin_TP(...)	TSPERR(TSS_E_INTERNAL_ERROR)
 #define RPC_DaaSign_TP(...)	TSPERR(TSS_E_INTERNAL_ERROR)
