@@ -40,26 +40,26 @@ Hash(UINT32 HashType, UINT32 BufSize, BYTE* Buf, BYTE* Digest)
 			rv = EVP_DigestInit(&md_ctx, EVP_sha1());
 			break;
 		default:
-			rv = TSPERR(TSS_E_BAD_PARAMETER);
+			rv = TCSERR(TSS_E_BAD_PARAMETER);
 			goto out;
 			break;
 	}
 
 	if (rv != EVP_SUCCESS) {
-		rv = TSPERR(TSS_E_INTERNAL_ERROR);
+		rv = TCSERR(TSS_E_INTERNAL_ERROR);
 		goto out;
 	}
 
 	rv = EVP_DigestUpdate(&md_ctx, Buf, BufSize);
 	if (rv != EVP_SUCCESS) {
-		rv = TSPERR(TSS_E_INTERNAL_ERROR);
+		rv = TCSERR(TSS_E_INTERNAL_ERROR);
 		goto out;
 	}
 
 	result_size = EVP_MD_CTX_size(&md_ctx);
 	rv = EVP_DigestFinal(&md_ctx, Digest, &result_size);
 	if (rv != EVP_SUCCESS) {
-		rv = TSPERR(TSS_E_INTERNAL_ERROR);
+		rv = TCSERR(TSS_E_INTERNAL_ERROR);
 	} else
 		rv = TSS_SUCCESS;
 
