@@ -42,6 +42,9 @@ tcs_wrap_RegisterKey(struct tcsd_thread_data *data)
 	if (getData(TCSD_PACKET_TYPE_UINT32, 0, &hContext, 0, &data->comm))
 		return TCSERR(TSS_E_INTERNAL_ERROR);
 
+	if ((result = ctx_verify_context(hContext)))
+		goto done;
+
 	LogDebugFn("thread %ld context %x", THREAD_ID, hContext);
 
 	if (getData(TCSD_PACKET_TYPE_UUID, 1, &WrappingKeyUUID, 0, &data->comm))
@@ -87,7 +90,7 @@ tcs_wrap_RegisterKey(struct tcsd_thread_data *data)
 				     gbVendorData);
 	free(rgbKey);
 	free(gbVendorData);
-
+done:
 	initData(&data->comm, 0);
 	data->comm.hdr.u.result = result;
 	return TSS_SUCCESS;
@@ -103,13 +106,16 @@ tcs_wrap_UnregisterKey(struct tcsd_thread_data *data)
 	if (getData(TCSD_PACKET_TYPE_UINT32, 0, &hContext, 0, &data->comm))
 		return TCSERR(TSS_E_INTERNAL_ERROR);
 
+	if ((result = ctx_verify_context(hContext)))
+		goto done;
+
 	LogDebugFn("thread %ld context %x", THREAD_ID, hContext);
 
 	if (getData(TCSD_PACKET_TYPE_UUID, 1, &uuid, 0, &data->comm))
 		return TCSERR(TSS_E_INTERNAL_ERROR);
 
 	result = TCS_UnregisterKey_Internal(hContext, uuid);
-
+done:
 	initData(&data->comm, 0);
 	data->comm.hdr.u.result = result;
 
@@ -128,6 +134,9 @@ tcs_wrap_GetRegisteredKeyBlob(struct tcsd_thread_data *data)
 	if (getData(TCSD_PACKET_TYPE_UINT32, 0, &hContext, 0, &data->comm))
 		return TCSERR(TSS_E_INTERNAL_ERROR);
 
+	if ((result = ctx_verify_context(hContext)))
+		goto done;
+
 	LogDebugFn("thread %ld context %x", THREAD_ID, hContext);
 
 	if (getData(TCSD_PACKET_TYPE_UUID, 1, &uuid, 0, &data->comm))
@@ -148,7 +157,7 @@ tcs_wrap_GetRegisteredKeyBlob(struct tcsd_thread_data *data)
 		}
 		free(prgbKey);
 	} else
-		initData(&data->comm, 0);
+done:		initData(&data->comm, 0);
 
 	data->comm.hdr.u.result = result;
 	return TSS_SUCCESS;
@@ -166,6 +175,9 @@ tcs_wrap_LoadKeyByUUID(struct tcsd_thread_data *data)
 	if (getData(TCSD_PACKET_TYPE_UINT32, 0, &hContext, 0, &data->comm))
 		return TCSERR(TSS_E_INTERNAL_ERROR);
 
+	if ((result = ctx_verify_context(hContext)))
+		goto done;
+
 	LogDebugFn("thread %ld context %x", THREAD_ID, hContext);
 
 	if (getData(TCSD_PACKET_TYPE_UUID, 1, &uuid, 0, &data->comm))
@@ -198,7 +210,7 @@ tcs_wrap_LoadKeyByUUID(struct tcsd_thread_data *data)
 				return TCSERR(TSS_E_INTERNAL_ERROR);
 			}
 		} else
-			initData(&data->comm, 0);
+done:			initData(&data->comm, 0);
 
 	}
 	data->comm.hdr.u.result = result;
@@ -219,6 +231,9 @@ tcs_wrap_EnumRegisteredKeys(struct tcsd_thread_data *data)
 	if (getData(TCSD_PACKET_TYPE_UINT32, 0, &hContext, 0, &data->comm))
 		return TCSERR(TSS_E_INTERNAL_ERROR);
 
+	if ((result = ctx_verify_context(hContext)))
+		goto done;
+
 	LogDebugFn("thread %ld context %x", THREAD_ID, hContext);
 
 	result = getData(TCSD_PACKET_TYPE_UUID , 1, &uuid, 0, &data->comm);
@@ -251,7 +266,7 @@ tcs_wrap_EnumRegisteredKeys(struct tcsd_thread_data *data)
 		}
 		free(pKeyHierarchy);
 	} else
-		initData(&data->comm, 0);
+done:		initData(&data->comm, 0);
 
 	data->comm.hdr.u.result = result;
 
@@ -272,6 +287,9 @@ tcs_wrap_EnumRegisteredKeys2(struct tcsd_thread_data *data)
 	if (getData(TCSD_PACKET_TYPE_UINT32, 0, &hContext, 0, &data->comm))
 		return TCSERR(TSS_E_INTERNAL_ERROR);
 
+	if ((result = ctx_verify_context(hContext)))
+		goto done;
+
 	LogDebugFn("thread %ld context %x", THREAD_ID, hContext);
 
 	result = getData(TCSD_PACKET_TYPE_UUID , 1, &uuid, 0, &data->comm);
@@ -304,7 +322,7 @@ tcs_wrap_EnumRegisteredKeys2(struct tcsd_thread_data *data)
 		}
 		free(pKeyHierarchy);
 	} else
-		initData(&data->comm, 0);
+done:		initData(&data->comm, 0);
 
 	data->comm.hdr.u.result = result;
 
@@ -322,6 +340,9 @@ tcs_wrap_GetRegisteredKeyByPublicInfo(struct tcsd_thread_data *data)
 	if (getData(TCSD_PACKET_TYPE_UINT32, 0, &hContext, 0, &data->comm))
 		return TCSERR(TSS_E_INTERNAL_ERROR);
 
+	if ((result = ctx_verify_context(hContext)))
+		goto done;
+
 	LogDebugFn("thread %ld context %x", THREAD_ID, hContext);
 
 	if (getData(TCSD_PACKET_TYPE_UINT32, 1, &algId, 0, &data->comm))
@@ -355,7 +376,7 @@ tcs_wrap_GetRegisteredKeyByPublicInfo(struct tcsd_thread_data *data)
 		}
 		free(keyBlob);
 	} else
-		initData(&data->comm, 0);
+done:		initData(&data->comm, 0);
 
 	data->comm.hdr.u.result = result;
 
