@@ -54,13 +54,14 @@ obj_context_add(TSS_HOBJECT *phObject)
 	context->connection_policy = TSS_TSPATTRIB_CONTEXT_VERSION_V1_1;
 
 	if ((result = obj_list_add(&context_list, NULL_HCONTEXT, 0, context, phObject))) {
+		free(context->machineName);
 		free(context);
 		return result;
 	}
 
 	/* Add the default policy */
 	if ((result = obj_policy_add(*phObject, TSS_POLICY_USAGE, &context->policy))) {
-		obj_list_remove(&context_list, &context_free, *phObject, *phObject);
+		obj_list_remove(&context_list, &__tspi_obj_context_free, *phObject, *phObject);
 		return result;
 	}
 
@@ -95,7 +96,7 @@ obj_context_get_tcs_api(TSS_HCONTEXT tspContext)
 }
 
 void
-context_free(void *data)
+__tspi_obj_context_free(void *data)
 {
 	struct tr_context_obj *context = (struct tr_context_obj *)data;
 
@@ -128,17 +129,19 @@ obj_context_close(TSS_HCONTEXT tspContext)
 
 	context = (struct tr_context_obj *)obj->data;
 
+#ifdef TSS_BUILD_TRANSPORT
 	if (context->transAuth.AuthHandle) {
 		RPC_FlushSpecific(tspContext, context->transAuth.AuthHandle, TPM_RT_TRANS);
 
-		memset(&context->transPub, 0, sizeof(TPM_TRANSPORT_PUBLIC));
-		memset(&context->transMod, 0, sizeof(TPM_MODIFIER_INDICATOR));
-		memset(&context->transSecret, 0, sizeof(TPM_TRANSPORT_AUTH));
-		memset(&context->transAuth, 0, sizeof(TPM_AUTH));
-		memset(&context->transLogIn, 0, sizeof(TPM_TRANSPORT_LOG_IN));
-		memset(&context->transLogOut, 0, sizeof(TPM_TRANSPORT_LOG_OUT));
-		memset(&context->transLogDigest, 0, sizeof(TPM_DIGEST));
+		__tspi_memset(&context->transPub, 0, sizeof(TPM_TRANSPORT_PUBLIC));
+		__tspi_memset(&context->transMod, 0, sizeof(TPM_MODIFIER_INDICATOR));
+		__tspi_memset(&context->transSecret, 0, sizeof(TPM_TRANSPORT_AUTH));
+		__tspi_memset(&context->transAuth, 0, sizeof(TPM_AUTH));
+		__tspi_memset(&context->transLogIn, 0, sizeof(TPM_TRANSPORT_LOG_IN));
+		__tspi_memset(&context->transLogOut, 0, sizeof(TPM_TRANSPORT_LOG_OUT));
+		__tspi_memset(&context->transLogDigest, 0, sizeof(TPM_DIGEST));
 	}
+#endif
 
 	obj_list_put(&context_list);
 }
@@ -173,7 +176,7 @@ obj_context_get_machine_name(TSS_HCONTEXT tspContext, UINT32 *size, BYTE **data)
 {
 	struct tsp_object *obj;
 	struct tr_context_obj *context;
-	TSS_RESULT result = TSPERR(TSS_E_INVALID_HANDLE);
+	TSS_RESULT result;
 
 	if ((obj = obj_list_get_obj(&context_list, tspContext)) == NULL)
 		return TSPERR(TSS_E_INVALID_HANDLE);
@@ -184,7 +187,11 @@ obj_context_get_machine_name(TSS_HCONTEXT tspContext, UINT32 *size, BYTE **data)
 		*data = NULL;
 		*size = 0;
 	} else {
-		*data = calloc_tspi(obj->tspContext, context->machineNameLength);
+		/*
+		 * Don't use calloc_tspi because this memory is
+		 * not freed using "free_tspi"
+		 */
+		*data = calloc(1, context->machineNameLength);
 		if (*data == NULL) {
 			LogError("malloc of %u bytes failed.",
 					context->machineNameLength);
@@ -213,7 +220,7 @@ obj_context_get_machine_name_attrib(TSS_HCONTEXT tspContext, UINT32 *size, BYTE
 	struct tr_context_obj *context;
 	BYTE *utf_string;
 	UINT32 utf_size;
-	TSS_RESULT result = TSPERR(TSS_E_INVALID_HANDLE);
+	TSS_RESULT result;
 
 	if ((obj = obj_list_get_obj(&context_list, tspContext)) == NULL)
 		return TSPERR(TSS_E_INVALID_HANDLE);
@@ -438,6 +445,7 @@ obj_context_set_connection_policy(TSS_HCONTEXT tspContext, UINT32 policy)
 	return TSS_SUCCESS;
 }
 
+#ifdef TSS_BUILD_TRANSPORT
 TSS_RESULT
 obj_context_set_transport_key(TSS_HCONTEXT tspContext, TSS_HKEY hKey)
 {
@@ -759,7 +767,7 @@ obj_context_transport_establish(TSS_HCONTEXT tspContext, struct tr_context_obj *
 
 		/* encrypt the sym key with the wrapping RSA key */
 		encKeyLen = sizeof(encKey);
-		if ((result = rsa_encrypt(context->transKey, secretLen, transAuthBlob, &encKeyLen,
+		if ((result = __tspi_rsa_encrypt(context->transKey, secretLen, transAuthBlob, &encKeyLen,
 					  encKey)))
 			return result;
 
@@ -787,7 +795,7 @@ obj_context_transport_establish(TSS_HCONTEXT tspContext, struct tr_context_obj *
 		tcsTransKey = TPM_KH_TRANSPORT;
 
 	/* If logging is on, do TPM commands spec rev106 step 8.a */
-	memset(context->transLogDigest.digest, 0, sizeof(TPM_DIGEST));
+	__tspi_memset(context->transLogDigest.digest, 0, sizeof(TPM_DIGEST));
 	if (context->flags & TSS_CONTEXT_FLAGS_TRANSPORT_AUTHENTIC) {
 		context->transLogIn.tag = TPM_TAG_TRANSPORT_LOG_IN;
 
@@ -801,7 +809,7 @@ obj_context_transport_establish(TSS_HCONTEXT tspContext, struct tr_context_obj *
 			return result;
 
 		/* step 8.a, ii */
-		memset(context->transLogIn.pubKeyHash.digest, 0, sizeof(TPM_DIGEST));
+		__tspi_memset(context->transLogIn.pubKeyHash.digest, 0, sizeof(TPM_DIGEST));
 
 		/* step 8.a, iii */
 		result = Trspi_HashInit(&hashCtx, TSS_HASH_SHA1);
@@ -959,6 +967,7 @@ do_transport_decryption(TPM_TRANSPORT_PUBLIC *transPub,
 	default:
 		LogDebug("Unknown algorithm for encrypted transport session: 0x%x",
 			 transPub->algId);
+		free(dec);
 		return TSPERR(TSS_E_INTERNAL_ERROR);
 	}
 
@@ -1038,6 +1047,7 @@ do_transport_encryption(TPM_TRANSPORT_PUBLIC *transPub,
 	default:
 		LogDebug("Unknown algorithm for encrypted transport session: 0x%x",
 			 transPub->algId);
+		free(enc);
 		return TSPERR(TSS_E_INTERNAL_ERROR);
 	}
 
@@ -1103,7 +1113,7 @@ obj_context_transport_execute(TSS_HCONTEXT     tspContext,
 			memcpy(context->transLogIn.pubKeyHash.digest, pubKeyHash->digest,
 			       sizeof(TPM_DIGEST));
 		else
-			memset(context->transLogIn.pubKeyHash.digest, 0, sizeof(TPM_DIGEST));
+			__tspi_memset(context->transLogIn.pubKeyHash.digest, 0, sizeof(TPM_DIGEST));
 
 		/* TPM Commands spec rev106 step 10.f */
 		result = Trspi_HashInit(&hashCtx, TSS_HASH_SHA1);
@@ -1410,13 +1420,13 @@ obj_context_transport_close(TSS_HCONTEXT   tspContext,
 	signInfo->dataLen = sizeof(TPM_DIGEST);
 
 	/* destroy all transport session info, except the key handle */
-	memset(&context->transPub, 0, sizeof(TPM_TRANSPORT_PUBLIC));
-	memset(&context->transMod, 0, sizeof(TPM_MODIFIER_INDICATOR));
-	memset(&context->transSecret, 0, sizeof(TPM_TRANSPORT_AUTH));
-	memset(&context->transAuth, 0, sizeof(TPM_AUTH));
-	memset(&context->transLogIn, 0, sizeof(TPM_TRANSPORT_LOG_IN));
-	memset(&context->transLogOut, 0, sizeof(TPM_TRANSPORT_LOG_OUT));
-	memset(&context->transLogDigest, 0, sizeof(TPM_DIGEST));
+	__tspi_memset(&context->transPub, 0, sizeof(TPM_TRANSPORT_PUBLIC));
+	__tspi_memset(&context->transMod, 0, sizeof(TPM_MODIFIER_INDICATOR));
+	__tspi_memset(&context->transSecret, 0, sizeof(TPM_TRANSPORT_AUTH));
+	__tspi_memset(&context->transAuth, 0, sizeof(TPM_AUTH));
+	__tspi_memset(&context->transLogIn, 0, sizeof(TPM_TRANSPORT_LOG_IN));
+	__tspi_memset(&context->transLogOut, 0, sizeof(TPM_TRANSPORT_LOG_OUT));
+	__tspi_memset(&context->transLogDigest, 0, sizeof(TPM_DIGEST));
 
 done_disabled:
 	context->flags &= ~TSS_CONTEXT_FLAGS_TRANSPORT_ESTABLISHED;
@@ -1425,6 +1435,7 @@ done:
 
 	return result;
 }
+#endif
 
 /* XXX change 0,1,2 to #defines */
 TSS_RESULT
